@@ -5,6 +5,6 @@ ABSDATASET
 
 __title__ = "absdataset"
 __license__ = "MIT License"
-__version__ = "1.0.0"
+__version__ = "1.1.0"
 
-from pkg_data import *
\ No newline at end of file
+from .pkg_data import *
\ No newline at end of file
